pub async fn import_from<S: SnapshotSource>(
cfg: &Config,
source: &S,
overwrite: bool,
) -> Result<PullReport>Expand description
Imports a source using one validation, incremental, and conflict policy.
pub async fn import_from<S: SnapshotSource>(
cfg: &Config,
source: &S,
overwrite: bool,
) -> Result<PullReport>Imports a source using one validation, incremental, and conflict policy.